package VMOMI::ClusterDasAamNodeStateDasState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
